@@ -59,10 +59,10 @@
 using namespace Akonadi;
 using namespace KAlarmCal;
 
-// Ensure CalendarDataModel::UserRole is valid. CalendarDataModel does not
-// include Akonadi headers, so here we check that it has been set to be
+// Ensure ResourceDataModelBase::UserRole is valid. ResourceDataModelBase does
+// not include Akonadi headers, so here we check that it has been set to be
 // compatible with EntityTreeModel::UserRole.
-static_assert((int)CalendarDataModel::UserRole>=(int)Akonadi::EntityTreeModel::UserRole, "CalendarDataModel::UserRole wrong value");
+static_assert((int)ResourceDataModelBase::UserRole>=(int)Akonadi::EntityTreeModel::UserRole, "ResourceDataModelBase::UserRole wrong value");
 
 /*=============================================================================
 = Class: AkonadiModel
@@ -86,13 +86,13 @@ AkonadiModel* AkonadiModel::instance()
 */
 AkonadiModel::AkonadiModel(ChangeRecorder* monitor, QObject* parent)
     : EntityTreeModel(monitor, parent)
-    , CalendarDataModel()
+    , ResourceDataModelBase()
     , mMonitor(monitor)
     , mMigrationChecked(false)
     , mMigrating(false)
 {
-    // Set lazy population to enable the contents of unselected collections to be ignored
-    setItemPopulationStrategy(LazyPopulation);
+    // Populate all collections, selected/enabled or unselected/disabled.
+    setItemPopulationStrategy(ImmediatePopulation);
 
     // Restrict monitoring to collections containing the KAlarm mime types
     monitor->setCollectionMonitored(Collection::root());
@@ -194,6 +194,11 @@ bool AkonadiModel::isMigrationCompleted() const
     return mMigrationChecked && !mMigrating;
 }
 
+ChangeRecorder* AkonadiModel::monitor()
+{
+    return instance()->mMonitor;
+}
+
 /******************************************************************************
 * Return the data for a given role, for a specified item.
 */
@@ -277,7 +282,7 @@ QVariant AkonadiModel::entityHeaderData(int section, Qt::Orientation orientation
         case CollectionTreeHeaders:
         {
             bool handled;
-            const QVariant value = CalendarDataModel::headerData(section, orientation, role, eventHeaders, handled);
+            const QVariant value = ResourceDataModelBase::headerData(section, orientation, role, eventHeaders, handled);
             if (handled)
                 return value;
             break;
@@ -425,7 +430,7 @@ bool AkonadiModel::reloadResource(const Resource& resource)
 }
 
 /******************************************************************************
-* Reload a collection from Akonadi storage. The backend data is not reloaded.
+* Reload all collections from Akonadi storage. The backend data is not reloaded.
 */
 void AkonadiModel::reload()
 {
@@ -622,7 +627,7 @@ void AkonadiModel::slotRowsInserted(const QModelIndex& parent, int start, int en
                     // Only notify new events if the collection is already populated.
                     // If not populated, all events will be notified when it is
                     // eventually populated.
-                    if (res.isLoaded())
+                    if (res.isPopulated())
                         events[res] += evnt;
                     mEventIds[evnt.id()] = EventIds(item.parentCollection().id(), item.id());
                 }
@@ -739,7 +744,7 @@ void AkonadiModel::slotCollectionRemoved(const Collection& collection)
     const Collection::Id id = collection.id();
     qCDebug(KALARM_LOG) << "AkonadiModel::slotCollectionRemoved:" << id;
     mResources.remove(collection.id());
-    Resources::removeResource(collection.id());
+    // AkonadiResource will remove the resource from Resources.
 }
 
 /******************************************************************************
