@@ -1,7 +1,7 @@
 /*
  *  alarmcalendar.cpp  -  KAlarm calendar file access
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1242,15 +1242,15 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
 
 /******************************************************************************
 * Return the event with the specified ID.
-* If 'checkDuplicates' is true, and the resource ID is invalid, if there is
-* a unique event with the given ID, it will be returned.
+* If 'findUniqueId' is true, and the resource ID is invalid, if there is a
+* unique event with the given ID, it will be returned.
 */
-KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool checkDuplicates)
+KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool findUniqueId)
 {
     if (!isValid())
         return nullptr;
     const QString eventId = uniqueID.eventId();
-    if (uniqueID.collectionId() == -1  &&  checkDuplicates)
+    if (uniqueID.collectionId() == -1  &&  findUniqueId)
     {
         // The resource isn't known, but use the event ID if it is unique among
         // all resources.
