@@ -20,7 +20,7 @@
 
 #include "alarmlistview.h"
 
-#include "calendardatamodel.h"
+#include "resources/resourcedatamodelbase.h"
 #include "resources/eventmodel.h"
 
 #include <ksharedconfig.h>
@@ -119,7 +119,7 @@ void AlarmListView::headerContextMenuRequested(const QPoint& pt)
     QMenu menu;
     for (int col = 0;  col < count;  ++col)
     {
-        const QString title = almodel->headerData(col, Qt::Horizontal, CalendarDataModel::ColumnTitleRole).toString();
+        const QString title = almodel->headerData(col, Qt::Horizontal, ResourceDataModelBase::ColumnTitleRole).toString();
         if (!title.isEmpty())
         {
             QAction* act = menu.addAction(title);
