@@ -1,7 +1,7 @@
 /*
  *  calendarmigrator.cpp  -  migrates or creates KAlarm Akonadi resources
  *  Program:  kalarm
- *  Copyright © 2011-2016 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2011-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,12 +19,15 @@
  */
 
 #include "calendarmigrator.h"
+
 #include "akonadimodel.h"
 #include "functions.h"
 #include "kalarmsettings.h"
 #include "kalarmdirsettings.h"
 #include "mainwindow.h"
 #include "messagebox.h"
+#include "resources/akonadiresource.h"
+#include "kalarm_debug.h"
 
 #include <kalarmcal/collectionattribute.h>
 #include <kalarmcal/compatibilityattribute.h>
@@ -44,7 +47,6 @@
 
 #include <QTimer>
 #include <QStandardPaths>
-#include "kalarm_debug.h"
 
 using namespace Akonadi;
 using namespace KAlarmCal;
@@ -108,7 +110,7 @@ class CalendarCreator : public QObject
         bool             mEnabled;
         bool             mStandard;
         const bool       mNew;     // true if creating default, false if converting
-        bool             mFinished;
+        bool             mFinished{false};
 };
 
 // Updates the backend calendar format of a single alarm calendar
@@ -142,8 +144,8 @@ CalendarMigrator* CalendarMigrator::mInstance = nullptr;
 bool              CalendarMigrator::mCompleted = false;
 
 CalendarMigrator::CalendarMigrator(QObject* parent)
-    : QObject(parent),
-      mExistingAlarmTypes{}
+    : QObject(parent)
+    , mExistingAlarmTypes{}
 {
 }
 
@@ -220,14 +222,14 @@ void CalendarMigrator::migrateOrCreate()
         CalendarCreator* creator;
         for (const QString& id : keys)
         {
-            const KConfigGroup configGroup = config.group(QStringLiteral("Resource_") + id);
+            const KConfigGroup configGroup = config.group(QLatin1String("Resource_") + id);
             const QString resourceType = configGroup.readEntry("ResourceType", QString());
             QString agentType;
-            if (resourceType == QStringLiteral("file"))
+            if (resourceType == QLatin1String("file"))
                 agentType = KALARM_RESOURCE;
-            else if (resourceType == QStringLiteral("dir"))
+            else if (resourceType == QLatin1String("dir"))
                 agentType = KALARM_DIR_RESOURCE;
-            else if (resourceType == QStringLiteral("remote"))
+            else if (resourceType == QLatin1String("remote"))
                 agentType = KALARM_RESOURCE;
             else
                 continue;   // unknown resource type - can't convert
@@ -377,12 +379,12 @@ void CalendarMigrator::calendarCreated(CalendarCreator* creator)
 * Note: the collection should be up to date: use AkonadiModel::refresh() before
 *       calling this function.
 */
-void CalendarMigrator::updateToCurrentFormat(const Collection& collection, bool ignoreKeepFormat, QWidget* parent)
+void CalendarMigrator::updateToCurrentFormat(const Resource& resource, bool ignoreKeepFormat, QWidget* parent)
 {
-    qCDebug(KALARM_LOG) << "CalendarMigrator::updateToCurrentFormat:" << collection.id();
-    if (CalendarUpdater::containsCollection(collection.id()))
+    qCDebug(KALARM_LOG) << "CalendarMigrator::updateToCurrentFormat:" << resource.id();
+    if (CalendarUpdater::containsCollection(resource.id()))
         return;   // prevent multiple simultaneous user prompts
-    const AgentInstance agent = AgentManager::self()->instance(collection.resource());
+    const AgentInstance agent = AgentManager::self()->instance(resource.configName());
     const QString id = agent.type().identifier();
     bool dirResource;
     if (id == KALARM_RESOURCE)
@@ -394,21 +396,25 @@ void CalendarMigrator::updateToCurrentFormat(const Collection& collection, bool
         qCCritical(KALARM_LOG) << "CalendarMigrator::updateToCurrentFormat: Invalid agent type" << id;
         return;
     }
+    const Collection& collection = AkonadiResource::collection(resource);
+    if (!parent)
+        parent = MainWindow::mainMainWindow();
     CalendarUpdater* updater = new CalendarUpdater(collection, dirResource, ignoreKeepFormat, false, parent);
     QTimer::singleShot(0, updater, &CalendarUpdater::update);
 }
 
+/*===========================================================================*/
 
 QList<CalendarUpdater*> CalendarUpdater::mInstances;
 
 CalendarUpdater::CalendarUpdater(const Collection& collection, bool dirResource,
                                  bool ignoreKeepFormat, bool newCollection, QObject* parent)
-    : mCollection(collection),
-      mParent(parent),
-      mDirResource(dirResource),
-      mIgnoreKeepFormat(ignoreKeepFormat),
-      mNewCollection(newCollection),
-      mDuplicate(containsCollection(collection.id()))
+    : mCollection(collection)
+    , mParent(parent)
+    , mDirResource(dirResource)
+    , mIgnoreKeepFormat(ignoreKeepFormat)
+    , mNewCollection(newCollection)
+    , mDuplicate(containsCollection(collection.id()))
 {
     mInstances.append(this);
 }
@@ -420,9 +426,9 @@ CalendarUpdater::~CalendarUpdater()
 
 bool CalendarUpdater::containsCollection(Collection::Id id)
 {
-    for (int i = 0, count = mInstances.count();  i < count;  ++i)
+    for (CalendarUpdater* instance : mInstances)
     {
-        if (mInstances[i]->mCollection.id() == id)
+        if (instance->mCollection.id() == id)
             return true;
     }
     return false;
@@ -432,11 +438,13 @@ bool CalendarUpdater::update()
 {
     qCDebug(KALARM_LOG) << "CalendarUpdater::update:" << mCollection.id() << (mDirResource ? "directory" : "file");
     bool result = true;
-    if (!mDuplicate     // prevent concurrent updates
-    &&  mCollection.hasAttribute<CompatibilityAttribute>())   // must know format to update
+    if (mDuplicate)
+        qCDebug(KALARM_LOG) << "CalendarUpdater::update: Not updating (concurrent update in progress)";
+    else if (mCollection.hasAttribute<CompatibilityAttribute>())   // must know format to update
     {
         const CompatibilityAttribute* compatAttr = mCollection.attribute<CompatibilityAttribute>();
         const KACalendar::Compat compatibility = compatAttr->compatibility();
+        qCDebug(KALARM_LOG) << "CalendarUpdater::update: current format:" << compatibility;
         if ((compatibility & ~KACalendar::Converted)
         // The calendar isn't in the current KAlarm format
         &&  !(compatibility & ~(KACalendar::Convertible | KACalendar::Converted)))
@@ -484,8 +492,8 @@ bool CalendarUpdater::update()
                 if (!mNewCollection)
                 {
                     // Record the user's choice of whether to update the calendar
-                    const QModelIndex ix = AkonadiModel::instance()->collectionIndex(mCollection);
-                    AkonadiModel::instance()->setData(ix, !result, AkonadiModel::KeepFormatRole);
+                    Resource resource = AkonadiModel::instance()->resource(mCollection.id());
+                    resource.setKeepFormat(!result);
                 }
             }
         }
@@ -522,7 +530,7 @@ template <class Interface> bool CalendarMigrator::updateStorageFormat(const Agen
 */
 template <class Interface> Interface* CalendarMigrator::getAgentInterface(const AgentInstance& agent, QString& errorMessage, QObject* parent)
 {
-    Interface* iface = new Interface(QStringLiteral("org.freedesktop.Akonadi.Resource.") + agent.identifier(),
+    Interface* iface = new Interface(QLatin1String("org.freedesktop.Akonadi.Resource.") + agent.identifier(),
               QStringLiteral("/Settings"), QDBusConnection::sessionBus(), parent);
     if (!iface->isValid())
     {
@@ -539,23 +547,22 @@ template <class Interface> Interface* CalendarMigrator::getAgentInterface(const
 * Constructor to migrate a KResources calendar, using its parameters.
 */
 CalendarCreator::CalendarCreator(const QString& resourceType, const KConfigGroup& config)
-    : mAlarmType(CalEvent::EMPTY),
-      mNew(false),
-      mFinished(false)
+    : mAlarmType(CalEvent::EMPTY)
+    , mNew(false)
 {
     // Read the resource configuration parameters from the config
     const char* pathKey = nullptr;
-    if (resourceType == QStringLiteral("file"))
+    if (resourceType == QLatin1String("file"))
     {
         mResourceType = LocalFile;
         pathKey = "CalendarURL";
     }
-    else if (resourceType == QStringLiteral("dir"))
+    else if (resourceType == QLatin1String("dir"))
     {
         mResourceType = LocalDir;
         pathKey = "CalendarURL";
     }
-    else if (resourceType == QStringLiteral("remote"))
+    else if (resourceType == QLatin1String("remote"))
     {
         mResourceType = RemoteFile;
         pathKey = "DownloadUrl";
@@ -589,15 +596,14 @@ CalendarCreator::CalendarCreator(const QString& resourceType, const KConfigGroup
 * This is created as enabled, read-write, and standard for its alarm type.
 */
 CalendarCreator::CalendarCreator(CalEvent::Type alarmType, const QString& file, const QString& name)
-    : mAlarmType(alarmType),
-      mResourceType(LocalFile),
-      mName(name),
-      mColour(),
-      mReadOnly(false),
-      mEnabled(true),
-      mStandard(true),
-      mNew(true),
-      mFinished(false)
+    : mAlarmType(alarmType)
+    , mResourceType(LocalFile)
+    , mName(name)
+    , mColour()
+    , mReadOnly(false)
+    , mEnabled(true)
+    , mStandard(true)
+    , mNew(true)
 {
     const QString path = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + file;
     mUrlString = QUrl::fromLocalFile(path).toString();
