@@ -1,7 +1,7 @@
 /*
  *  commandoptions.h  -  extract command line options
  *  Program:  kalarm
- *  Copyright © 2001-2017 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -147,37 +147,37 @@ class CommandOptions
         QString     optionName(Option, bool shortName = false) const;
 
         static CommandOptions* mFirstInstance;      // the first instance
-        QCommandLineParser* mParser;
-        QVector<QCommandLineOption*> mOptions;  // all possible command line options
-        QStringList         mNonExecArguments; // arguments except for --exec or --exec-display parameters
-        QStringList         mExecArguments;  // arguments for --exec or --exec-display
-        QString             mError;          // error message
-        Command             mCommand;        // the selected command
-        Option              mCommandOpt;     // option for the selected command
-        EventId             mEventId;        // TRIGGER_EVENT, CANCEL_EVENT, EDIT: event ID
-        QString             mTemplateName;   // EDIT_NEW_PRESET: template name
-        EditAlarmDlg::Type  mEditType;       // NEW, EDIT_NEW_*: alarm edit type
-        KAEvent::SubAction  mEditAction;     // NEW: alarm edit sub-type
-        bool                mEditActionSet;  // NEW: mEditAction is valid
-        QString             mText;           // NEW: alarm text
-        KADateTime          mAlarmTime;      // NEW: alarm time
-        KARecurrence*       mRecurrence;     // NEW: recurrence
-        int                 mRepeatCount;    // NEW: sub-repetition count
-        KCalendarCore::Duration  mRepeatInterval; // NEW: sub-repetition interval
-        int                 mLateCancel;     // NEW: late-cancellation interval
-        QColor              mBgColour;       // NEW: background colour
-        QColor              mFgColour;       // NEW: foreground colour
-        int                 mReminderMinutes;// NEW: reminder period
-        QString             mAudioFile;      // NEW: audio file path
-        float               mAudioVolume;    // NEW: audio file volume
-        KCalendarCore::Person::List mAddressees;  // NEW: email addressees
-        QStringList         mAttachments;    // NEW: email attachment file names
-        QString             mSubject;        // NEW: email subject
-        uint                mFromID;         // NEW: email sender ID
-        KAEvent::Flags      mFlags;          // NEW: event flags
-        bool                mDisableAll;     // disable all alarm monitoring
+        QCommandLineParser* mParser{nullptr};
+        QVector<QCommandLineOption*> mOptions;      // all possible command line options
+        QStringList         mNonExecArguments;      // arguments except for --exec or --exec-display parameters
+        QStringList         mExecArguments;         // arguments for --exec or --exec-display
+        QString             mError;                 // error message
+        Command             mCommand{NONE};         // the selected command
+        Option              mCommandOpt;            // option for the selected command
+        EventId             mEventId;               // TRIGGER_EVENT, CANCEL_EVENT, EDIT: event ID
+        QString             mTemplateName;          // EDIT_NEW_PRESET: template name
+        EditAlarmDlg::Type  mEditType;              // NEW, EDIT_NEW_*: alarm edit type
+        KAEvent::SubAction  mEditAction;            // NEW: alarm edit sub-type
+        bool                mEditActionSet{false};  // NEW: mEditAction is valid
+        QString             mText;                  // NEW: alarm text
+        KADateTime          mAlarmTime;             // NEW: alarm time
+        KARecurrence*       mRecurrence{nullptr};   // NEW: recurrence
+        int                 mRepeatCount{0};        // NEW: sub-repetition count
+        KCalendarCore::Duration mRepeatInterval{0}; // NEW: sub-repetition interval
+        int                 mLateCancel{0};         // NEW: late-cancellation interval
+        QColor              mBgColour;              // NEW: background colour
+        QColor              mFgColour;              // NEW: foreground colour
+        int                 mReminderMinutes{0};    // NEW: reminder period
+        QString             mAudioFile;             // NEW: audio file path
+        float               mAudioVolume{-1.0f};    // NEW: audio file volume
+        KCalendarCore::Person::List mAddressees;    // NEW: email addressees
+        QStringList         mAttachments;           // NEW: email attachment file names
+        QString             mSubject;               // NEW: email subject
+        uint                mFromID{0};             // NEW: email sender ID
+        KAEvent::Flags      mFlags;                 // NEW: event flags
+        bool                mDisableAll{false};     // disable all alarm monitoring
 #ifndef NDEBUG
-        KADateTime          mSimulationTime; // system time to be simulated, or invalid if none
+        KADateTime          mSimulationTime;        // system time to be simulated, or invalid if none
 #endif
 };
 
