@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "editdlgtypes.h"
 #include "editdlg_p.h"
 
@@ -46,6 +45,7 @@
 #include "specialactions.h"
 #include "templatepickdlg.h"
 #include "timespinbox.h"
+#include "kalarm_debug.h"
 
 #include <kalarmcal/identities.h>
 
@@ -67,7 +67,6 @@ using namespace KCalendarCore;
 #include <QVBoxLayout>
 #include <QDragEnterEvent>
 #include <QStandardItemModel>
-#include "kalarm_debug.h"
 
 using namespace KAlarmCal;
 
@@ -80,15 +79,15 @@ enum { tTEXT, tFILE, tCOMMAND };  // order of mTypeCombo items
 class PickLogFileRadio : public PickFileRadio
 {
     public:
-    PickLogFileRadio(QPushButton* b, LineEdit* e, const QString& text, ButtonGroup* group, QWidget* parent)
-        : PickFileRadio(b, e, text, group, parent) { }
-    QString pickFile() override    // called when browse button is pressed to select a log file
-    {
-        return KAlarm::browseFile(i18nc("@title:window", "Choose Log File"), mDefaultDir, fileEdit()->text(), QString(),
-                                  false, parentWidget());
-    }
+        PickLogFileRadio(QPushButton* b, LineEdit* e, const QString& text, ButtonGroup* group, QWidget* parent)
+            : PickFileRadio(b, e, text, group, parent) { }
+        bool pickFile(QString& file) override    // called when browse button is pressed to select a log file
+        {
+            return KAlarm::browseFile(file, i18nc("@title:window", "Choose Log File"), mDefaultDir, fileEdit()->text(), QString(),
+                                      false, parentWidget());
+        }
     private:
-    QString mDefaultDir;   // default directory for log file browse button
+        QString mDefaultDir;   // default directory for log file browse button
 };
 
 
@@ -108,10 +107,7 @@ QString EditDisplayAlarmDlg::i18n_chk_ConfirmAck()    { return i18nc("@option:ch
 *   event   != to initialise the dialog to show the specified event's data.
 */
 EditDisplayAlarmDlg::EditDisplayAlarmDlg(bool Template, QWidget* parent, GetResourceType getResource)
-    : EditAlarmDlg(Template, KAEvent::MESSAGE, parent, getResource),
-      mSpecialActionsButton(nullptr),
-      mReminderDeferral(false),
-      mReminderArchived(false)
+    : EditAlarmDlg(Template, KAEvent::MESSAGE, parent, getResource)
 {
     qCDebug(KALARM_LOG) << "EditDisplayAlarmDlg: New";
     init(nullptr);
@@ -119,10 +115,7 @@ EditDisplayAlarmDlg::EditDisplayAlarmDlg(bool Template, QWidget* parent, GetReso
 
 EditDisplayAlarmDlg::EditDisplayAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
                                          GetResourceType getResource, bool readOnly)
-    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly),
-      mSpecialActionsButton(nullptr),
-      mReminderDeferral(false),
-      mReminderArchived(false)
+    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly)
 {
     qCDebug(KALARM_LOG) << "EditDisplayAlarmDlg: Event.id()";
     init(event);
@@ -561,8 +554,8 @@ void EditDisplayAlarmDlg::type_setEvent(KAEvent& event, const KADateTime& dt, co
         default:
         case tTEXT:     type = KAEvent::MESSAGE; break;
     }
-    event.set(dt, text, mFontColourButton->bgColour(), mFontColourButton->fgColour(), mFontColourButton->font(),
-              type, lateCancel, getAlarmFlags());
+    event = KAEvent(dt, text, mFontColourButton->bgColour(), mFontColourButton->fgColour(),
+                    mFontColourButton->font(), type, lateCancel, getAlarmFlags());
     if (type == KAEvent::MESSAGE)
     {
         if (AlarmText::checkIfEmail(text))
@@ -646,12 +639,15 @@ void EditDisplayAlarmDlg::slotAlarmTypeChanged(int index)
 void EditDisplayAlarmDlg::slotPickFile()
 {
     static QString defaultDir;   // default directory for file browse button
-    QString file = KAlarm::browseFile(i18nc("@title:window", "Choose Text or Image File to Display"),
-                                      defaultDir, mFileMessageEdit->text(), QString(), true, this);
-    if (!file.isEmpty())
+    QString file;
+    if (KAlarm::browseFile(file, i18nc("@title:window", "Choose Text or Image File to Display"),
+                                      defaultDir, mFileMessageEdit->text(), QString(), true, this))
     {
-        mFileMessageEdit->setText(KAlarm::pathOrUrl(file));
-        contentsChanged();
+        if (!file.isEmpty())
+        {
+            mFileMessageEdit->setText(KAlarm::pathOrUrl(file));
+            contentsChanged();
+        }
     }
 }
 
@@ -933,7 +929,7 @@ bool EditCommandAlarmDlg::type_stateChanged() const
 void EditCommandAlarmDlg::type_setEvent(KAEvent& event, const KADateTime& dt, const QString& text, int lateCancel, bool trial)
 {
     Q_UNUSED(trial);
-    event.set(dt, text, QColor(), QColor(), QFont(), KAEvent::COMMAND, lateCancel, getAlarmFlags());
+    event = KAEvent(dt, text, QColor(), QColor(), QFont(), KAEvent::COMMAND, lateCancel, getAlarmFlags());
     if (mCmdOutputGroup->checkedButton() == mCmdLogToFile)
         event.setLogFile(mCmdLogFileEdit->text());
 }
@@ -1050,8 +1046,7 @@ QString EditEmailAlarmDlg::i18n_chk_CopyEmailToSelf()    { return i18nc("@option
 *   event   != to initialise the dialog to show the specified event's data.
 */
 EditEmailAlarmDlg::EditEmailAlarmDlg(bool Template, QWidget* parent, GetResourceType getResource)
-    : EditAlarmDlg(Template, KAEvent::EMAIL, parent, getResource),
-      mEmailRemoveButton(nullptr)
+    : EditAlarmDlg(Template, KAEvent::EMAIL, parent, getResource)
 {
     qCDebug(KALARM_LOG) << "EditEmailAlarmDlg: New";
     init(nullptr);
@@ -1059,8 +1054,7 @@ EditEmailAlarmDlg::EditEmailAlarmDlg(bool Template, QWidget* parent, GetResource
 
 EditEmailAlarmDlg::EditEmailAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
                                      GetResourceType getResource, bool readOnly)
-    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly),
-      mEmailRemoveButton(nullptr)
+    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly)
 {
     qCDebug(KALARM_LOG) << "EditEmailAlarmDlg: Event.id()";
     init(event);
@@ -1321,7 +1315,7 @@ bool EditEmailAlarmDlg::type_stateChanged() const
 void EditEmailAlarmDlg::type_setEvent(KAEvent& event, const KADateTime& dt, const QString& text, int lateCancel, bool trial)
 {
     Q_UNUSED(trial);
-    event.set(dt, text, QColor(), QColor(), QFont(), KAEvent::EMAIL, lateCancel, getAlarmFlags());
+    event = KAEvent(dt, text, QColor(), QColor(), QFont(), KAEvent::EMAIL, lateCancel, getAlarmFlags());
     uint from = mEmailFromList ? mEmailFromList->currentIdentity() : 0;
     event.setEmail(from, mEmailAddresses, mEmailSubjectEdit->text(), mEmailAttachments);
 }
@@ -1441,15 +1435,18 @@ void EditEmailAlarmDlg::openAddressBook()
 */
 void EditEmailAlarmDlg::slotAddAttachment()
 {
-    QString url = KAlarm::browseFile(i18nc("@title:window", "Choose File to Attach"), mAttachDefaultDir, QString(),
-                                     QString(), true, this);
-    if (!url.isEmpty())
+    QString file;
+    if (KAlarm::browseFile(file, i18nc("@title:window", "Choose File to Attach"),
+                           mAttachDefaultDir, QString(), QString(), true, this))
     {
-        mEmailAttachList->addItem(url);
-        mEmailAttachList->setCurrentIndex(mEmailAttachList->count() - 1);   // select the new item
-        mEmailRemoveButton->setEnabled(true);
-        mEmailAttachList->setEnabled(true);
-        contentsChanged();
+        if (!file.isEmpty())
+        {
+            mEmailAttachList->addItem(file);
+            mEmailAttachList->setCurrentIndex(mEmailAttachList->count() - 1);   // select the new item
+            mEmailRemoveButton->setEnabled(true);
+            mEmailAttachList->setEnabled(true);
+            contentsChanged();
+        }
     }
 }
 
@@ -1495,8 +1492,7 @@ bool EditEmailAlarmDlg::checkText(QString& result, bool showErrorMessage) const
 *   event   != to initialise the dialog to show the specified event's data.
 */
 EditAudioAlarmDlg::EditAudioAlarmDlg(bool Template, QWidget* parent, GetResourceType getResource)
-    : EditAlarmDlg(Template, KAEvent::AUDIO, parent, getResource),
-      mMessageWin(nullptr)
+    : EditAlarmDlg(Template, KAEvent::AUDIO, parent, getResource)
 {
     qCDebug(KALARM_LOG) << "EditAudioAlarmDlg: New";
     init(nullptr);
@@ -1504,8 +1500,7 @@ EditAudioAlarmDlg::EditAudioAlarmDlg(bool Template, QWidget* parent, GetResource
 
 EditAudioAlarmDlg::EditAudioAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
                                      GetResourceType getResource, bool readOnly)
-    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly),
-      mMessageWin(nullptr)
+    : EditAlarmDlg(Template, event, newAlarm, parent, getResource, readOnly)
 {
     qCDebug(KALARM_LOG) << "EditAudioAlarmDlg: Event.id()";
     init(event);
@@ -1631,7 +1626,7 @@ void EditAudioAlarmDlg::type_setEvent(KAEvent& event, const KADateTime& dt, cons
 {
     Q_UNUSED(text);
     Q_UNUSED(trial);
-    event.set(dt, QString(), QColor(), QColor(), QFont(), KAEvent::AUDIO, lateCancel, getAlarmFlags());
+    event = KAEvent(dt, QString(), QColor(), QColor(), QFont(), KAEvent::AUDIO, lateCancel, getAlarmFlags());
     float volume, fadeVolume;
     int   fadeSecs;
     mSoundConfig->getVolume(volume, fadeVolume, fadeSecs);
