@@ -26,7 +26,6 @@
 
 #include <kalarmcal/alarmtext.h>
 #include <kalarmcal/kaevent.h>
-#include <AkonadiCore/item.h>
 
 using namespace KAlarmCal;
 
@@ -103,10 +102,10 @@ class EditDisplayAlarmDlg : public EditAlarmDlg
         SoundPicker*        mSoundPicker;
         CheckBox*           mConfirmAck;
         FontColourButton*   mFontColourButton;
-        SpecialActionsButton* mSpecialActionsButton;
+        SpecialActionsButton* mSpecialActionsButton{nullptr};
         Akonadi::Item::Id   mAkonadiItemId;      // if email text, message's Akonadi item ID, else -1
-        bool                mReminderDeferral;
-        bool                mReminderArchived;
+        bool                mReminderDeferral{false};
+        bool                mReminderArchived{false};
         // Text message alarm widgets
         TextEdit*           mTextMessageEdit;    // text message edit box
         // Text file alarm widgets
@@ -240,7 +239,7 @@ class EditEmailAlarmDlg : public EditAlarmDlg
         TextEdit*       mEmailMessageEdit;   // email body edit box
         QComboBox*      mEmailAttachList;
         QPushButton*    mEmailAddAttachButton;
-        QPushButton*    mEmailRemoveButton;
+        QPushButton*    mEmailRemoveButton{nullptr};
         CheckBox*       mEmailBcc;
         QString         mAttachDefaultDir;
 
@@ -293,7 +292,7 @@ class EditAudioAlarmDlg : public EditAlarmDlg
         void            slotAudioPlaying(bool playing);
 
     private:
-        MessageWin*     mMessageWin;       // MessageWin controlling test audio playback
+        MessageWin*     mMessageWin{nullptr}; // MessageWin controlling test audio playback
 
         // Audio alarm options
         SoundWidget*    mSoundConfig;
