@@ -1,7 +1,7 @@
 /*
  *  emailidcombo.h  -  email identity combo box with read-only option
  *  Program:  kalarm
- *  Copyright © 2004,2006 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004,2006 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ class EmailIdCombo : public KIdentityManagement::IdentityCombo
         void keyReleaseEvent(QKeyEvent*) override;
 
     private:
-        bool    mReadOnly;      // value cannot be changed
+        bool    mReadOnly{false};      // value cannot be changed
 };
 
 #endif // EMAILIDCOMBO_H
