@@ -18,13 +18,14 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "find.h"
 
 #include "alarmlistview.h"
 #include "eventlistview.h"
 #include "messagebox.h"
 #include "preferences.h"
+#include "resources/eventmodel.h"
+#include "kalarm_debug.h"
 
 #include <kalarmcal/kaevent.h>
 
@@ -41,7 +42,6 @@
 #include <QRegExp>
 #include <QStyle>
 #include <QApplication>
-#include "kalarm_debug.h"
 
 using namespace KAlarmCal;
 
@@ -59,12 +59,9 @@ static long FIND_KALARM_OPTIONS = FIND_LIVE | FIND_ARCHIVED | FIND_MESSAGE | FIN
 
 
 Find::Find(EventListView* parent)
-    : QObject(parent),
-      mListView(parent),
-      mDialog(nullptr),
-      mFind(nullptr),
-      mOptions(0),
-      mFound(false)
+    : QObject(parent)
+    , mListView(parent)
+    , mDialog(nullptr)
 {
     connect(mListView->selectionModel(), &QItemSelectionModel::currentChanged, this, &Find::slotSelectionChanged);
 }
@@ -195,10 +192,10 @@ void Find::display()
     bool command  = false;
     bool email    = false;
     bool audio    = false;
-    int rowCount = mListView->model()->rowCount();
+    const int rowCount = mListView->model()->rowCount();
     for (int row = 0;  row < rowCount;  ++row)
     {
-        KAEvent viewEvent = mListView->event(row);
+        const KAEvent viewEvent = mListView->event(row);
         const KAEvent* event = &viewEvent;
         if (event->expired())
             archived = true;
@@ -261,9 +258,9 @@ void Find::slotFind()
     }
 
     // Supply KFind with only those options which relate to the text within alarms
-    long options = mOptions & (KFind::WholeWordsOnly | KFind::CaseSensitive | KFind::RegularExpression);
-    bool newFind = !mFind;
-    bool newPattern = (mDialog->pattern() != mLastPattern);
+    const long options = mOptions & (KFind::WholeWordsOnly | KFind::CaseSensitive | KFind::RegularExpression);
+    const bool newFind = !mFind;
+    const bool newPattern = (mDialog->pattern() != mLastPattern);
     mLastPattern = mDialog->pattern();
     if (mFind)
     {
@@ -287,7 +284,7 @@ void Find::slotFind()
         mFound = false;
         if (mOptions & KFind::FromCursor)
         {
-            QModelIndex index = mListView->selectionModel()->currentIndex();
+            const QModelIndex index = mListView->selectionModel()->currentIndex();
             if (index.isValid())
             {
                 mStartID       = mListView->event(index).id();
@@ -321,12 +318,12 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
     bool last = false;
     for ( ;  index.isValid() && !last;  index = nextItem(index, forward))
     {
-        KAEvent viewEvent = mListView->event(index);
+        const KAEvent viewEvent = mListView->event(index);
         const KAEvent* event = &viewEvent;
         if (!fromCurrent  &&  !mStartID.isNull()  &&  mStartID == event->id())
             last = true;    // we've wrapped round and reached the starting alarm again
         fromCurrent = false;
-        bool live = !event->expired();
+        const bool live = !event->expired();
         if ((live  &&  !(mOptions & FIND_LIVE))
         ||  (!live  &&  !(mOptions & FIND_ARCHIVED)))
             continue;     // we're not searching this type of alarm
@@ -343,7 +340,7 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
                 found = (mFind->find() == KFind::Match);
                 if (found)
                     break;
-                mFind->setData(event->emailAttachments().join(QStringLiteral(", ")));
+                mFind->setData(event->emailAttachments().join(QLatin1String(", ")));
                 found = (mFind->find() == KFind::Match);
                 if (found)
                     break;
@@ -405,8 +402,8 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
         // No match was found
         if (mFound  ||  checkEnd)
         {
-            QString msg = forward ? xi18nc("@info", "<para>End of alarm list reached.</para><para>Continue from the beginning?</para>")
-                                  : xi18nc("@info", "<para>Beginning of alarm list reached.</para><para>Continue from the end?</para>");
+            const QString msg = forward ? xi18nc("@info", "<para>End of alarm list reached.</para><para>Continue from the beginning?</para>")
+                                        : xi18nc("@info", "<para>Beginning of alarm list reached.</para><para>Continue from the end?</para>");
             if (KAMessageBox::questionYesNo(mListView, msg, QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()) == KMessageBox::Yes)
             {
                 mNoCurrentItem = true;
@@ -440,4 +437,5 @@ QModelIndex Find::nextItem(const QModelIndex& index, bool forward) const
     else
         return mListView->indexAbove(index);
 }
+
 // vim: et sw=4:
