@@ -1,7 +1,7 @@
 /*
  *  colourbutton.h  -  colour selection button
  *  Program:  kalarm
- *  Copyright © 2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2008 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ class ColourButton : public KColorButton
         void         keyPressEvent(QKeyEvent*) override;
         void         keyReleaseEvent(QKeyEvent*) override;
     private:
-        bool         mReadOnly;        // value cannot be changed
+        bool         mReadOnly{false};        // value cannot be changed
 };
 
 #endif // COLOURBUTTON_H
