@@ -1,7 +1,7 @@
 /*
  *  combobox.h  -  combo box with read-only option
  *  Program:  kalarm
- *  Copyright © 2002,2005-2007 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002,2005-2007 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ class ComboBox : public KComboBox
         void         keyPressEvent(QKeyEvent*) override;
         void         keyReleaseEvent(QKeyEvent*) override;
     private:
-        bool    mReadOnly;      // value cannot be changed
+        bool    mReadOnly{false};      // value cannot be changed
 };
 
 #endif // COMBOBOX_H
