@@ -1,7 +1,7 @@
 /*
  *  groupbox.h  -  checkable group box with read-only option
  *  Program:  kalarm
- *  Copyright © 2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2011,2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ class GroupBox : public QGroupBox
         void         keyPressEvent(QKeyEvent*) override;
         void         keyReleaseEvent(QKeyEvent*) override;
     private:
-        bool  mReadOnly;      // value cannot be changed
+        bool  mReadOnly{false};      // value cannot be changed
 };
 
 #endif // GROUPBOX_H
