@@ -1,7 +1,7 @@
 /*
  *  kalocale.cpp  -  miscellaneous locale functions
  *  Program:  kalarm
- *  Copyright © 2003-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2003-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"   //krazy:exclude=includes (kalarm.h must be first)
 #include "kalocale.h"
 
 #include "kalarm_debug.h"
+
 #include <QLocale>
 
 namespace
@@ -44,16 +44,16 @@ int localeFirstDayOfWeek()
         locale = QLocale();
         firstDay = locale.firstDayOfWeek();
         QList<Qt::DayOfWeek> weekDays = locale.weekdays();
-        for (int i = 0; i < weekDays.size(); ++i)
-            workDays |= 1 << (weekDays.at(i) - 1);
+        for (Qt::DayOfWeek weekDay : qAsConst(weekDays))
+            workDays |= 1 << (weekDay - 1);
 
         std::sort(weekDays.begin(), weekDays.end());
         int day = 0;
-        for (int i = 0; i < weekDays.size(); ++i)
-            if (++day < weekDays.at(i))
+        for (Qt::DayOfWeek weekDay : qAsConst(weekDays))
+            if (++day < weekDay)
             {
                 lastWorkDay = (day == 1) ? weekDays.at(weekDays.size() - 1) : day - 1;
-                firstWorkDay = weekDays.at(i);
+                firstWorkDay = weekDay;
                 break;
             }
     }
