@@ -1,7 +1,7 @@
 /*
  *  label.h  -  label with radiobutton buddy option
  *  Program:  kalarm
- *  Copyright © 2004-2006 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -77,8 +77,8 @@ class Label : public QLabel
 
     private:
         void              activated();
-        QRadioButton*     mRadioButton;   // buddy widget if it's a radio button, else 0
-        LabelFocusWidget* mFocusWidget;
+        QRadioButton*     mRadioButton{nullptr};  // buddy widget if it's a radio button, else 0
+        LabelFocusWidget* mFocusWidget{nullptr};
 };
 
 
