@@ -1,7 +1,7 @@
 /*
  *  packedlayout.h  -  layout to pack items into rows
  *  Program:  kalarm
- *  Copyright © 2007 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,9 +55,10 @@ class PackedLayout : public QLayout
 
     private:
         int              arrange(const QRect&, bool set) const;
+
         QList<QLayoutItem*> mItems;
         Qt::Alignment       mAlignment;
-        mutable int         mWidthCached;
+        mutable int         mWidthCached{0};
         mutable int         mHeightCached;
 };
 
