@@ -1,7 +1,7 @@
 /*
  *  radiobutton.h  -  radio button with focus widget and read-only options
  *  Program:  kalarm
- *  Copyright © 2002,2003,2005,2006 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -49,40 +49,48 @@ class RadioButton : public QRadioButton
          *  @param parent The parent object of this widget.
          */
         explicit RadioButton(QWidget* parent = nullptr);
+
         /** Constructor.
          *  @param text Text to display.
          *  @param parent The parent object of this widget.
          */
-        RadioButton(const QString& text, QWidget* parent = nullptr);
+        explicit RadioButton(const QString& text, QWidget* parent = nullptr);
+
         /** Returns true if the widget is read only. */
-        bool     isReadOnly() const          { return mReadOnly; }
+        bool isReadOnly() const          { return mReadOnly; }
+
         /** Sets whether the radio button is read-only for the user. If read-only,
          *  its state cannot be changed by the user.
          *  @param readOnly True to set the widget read-only, false to set it read-write.
          */
         virtual void setReadOnly(bool readOnly);
+
         /** Returns the widget which receives focus when the button is clicked. */
         QWidget* focusWidget() const         { return mFocusWidget; }
+
         /** Specifies a widget to receive focus when the button is clicked.
          *  @param widget Widget to receive focus.
          *  @param enable If true, @p widget will be enabled before receiving focus. If
          *                false, the enabled state of @p widget will be left unchanged when
          *                the radio button is clicked.
          */
-        void     setFocusWidget(QWidget* widget, bool enable = true);
+        void setFocusWidget(QWidget* widget, bool enable = true);
+
     protected:
         void     mousePressEvent(QMouseEvent*) override;
         void     mouseReleaseEvent(QMouseEvent*) override;
         void     mouseMoveEvent(QMouseEvent*) override;
         void     keyPressEvent(QKeyEvent*) override;
         void     keyReleaseEvent(QKeyEvent*) override;
+
     protected Q_SLOTS:
         void     slotClicked();
+
     private:
-        Qt::FocusPolicy mFocusPolicy;       // default focus policy for the QRadioButton
-        QWidget*        mFocusWidget;       // widget to receive focus when button is clicked on
-        bool            mFocusWidgetEnable; // enable focus widget before setting focus
-        bool            mReadOnly;          // value cannot be changed
+        Qt::FocusPolicy mFocusPolicy;           // default focus policy for the QRadioButton
+        QWidget*        mFocusWidget{nullptr};  // widget to receive focus when button is clicked on
+        bool            mFocusWidgetEnable;     // enable focus widget before setting focus
+        bool            mReadOnly{false};       // value cannot be changed
 };
 
 #endif // RADIOBUTTON_H
