@@ -1,7 +1,7 @@
 /*
  *  spinbox.cpp  -  spin box with read-only option and shift-click step value
  *  Program:  kalarm
- *  Copyright © 2002,2004-2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 
 #include "spinbox.h"
 
+#include "kalarm_debug.h"
+
 #include <QLineEdit>
 #include <QObject>
 #include <QApplication>
@@ -29,22 +31,21 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 #include <QEvent>
-#include "kalarm_debug.h"
 
 
 SpinBox::SpinBox(QWidget* parent)
-    : QSpinBox(parent),
-      mMinValue(QSpinBox::minimum()),
-      mMaxValue(QSpinBox::maximum())
+    : QSpinBox(parent)
+    , mMinValue(QSpinBox::minimum())
+    , mMaxValue(QSpinBox::maximum())
 {
     setRange(0, 99999);
     init();
 }
 
 SpinBox::SpinBox(int minValue, int maxValue, QWidget* parent)
-    : QSpinBox(parent),
-      mMinValue(minValue),
-      mMaxValue(maxValue)
+    : QSpinBox(parent)
+    , mMinValue(minValue)
+    , mMaxValue(maxValue)
 {
     setRange(minValue, maxValue);
     init();
@@ -56,14 +57,6 @@ void SpinBox::init()
     mLineStep        = step;
     mLineShiftStep   = step;
     mCurrentButton   = NO_BUTTON;
-    mShiftMouse      = false;
-    mShiftMinBound   = false;
-    mShiftMaxBound   = false;
-    mSelectOnStep    = true;
-    mUpDownOnly      = false;
-    mReadOnly        = false;
-    mSuppressSignals = false;
-    mEdited          = false;
 
     lineEdit()->installEventFilter(this);   // handle shift-up/down arrow presses
 
@@ -206,7 +199,7 @@ bool SpinBox::eventFilter(QObject* obj, QEvent* e)
             case QEvent::Wheel:
             {
                 QWheelEvent* we = (QWheelEvent*)e;
-                step = (we->delta() > 0) ? 1 : -1;
+                step = (we->angleDelta().y() > 0) ? 1 : -1;
                 break;
             }
             default:
@@ -285,7 +278,7 @@ void SpinBox::wheelEvent(QWheelEvent* e)
     if (mReadOnly)
         return;   // discard the event
     bool shift = (e->modifiers() & (Qt::ShiftModifier | Qt::AltModifier)) == Qt::ShiftModifier;
-    if (setShiftStepping(shift, (e->delta() > 0 ? UP : DOWN)))
+    if (setShiftStepping(shift, (e->angleDelta().y() > 0 ? UP : DOWN)))
     {
         e->accept();
         return;     // hide the event from the spin widget
