@@ -1,7 +1,7 @@
 /*
  *  synchtimer.cpp  -  timers which synchronize to time boundaries
  *  Program:  kalarm
- *  Copyright © 2004,2005,2007-2009 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004,2005,2007-2009 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,13 +18,13 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "synchtimer.h"
 
+#include "kalarm_debug.h"
+
 #include <QTimer>
 #include <QDateTime>
 #include <QTime>
-#include "kalarm_debug.h"
 
 /*=============================================================================
 =  Class: SynchTimer
@@ -203,7 +203,7 @@ void DailyTimer::changeTime(const QTime& newTimeOfDay, bool triggerMissed)
 void DailyTimer::start()
 {
     // TIMEZONE = local time
-    QDateTime now = QDateTime::currentDateTime();
+    const QDateTime now = QDateTime::currentDateTime();
     // Find out whether to trigger today or tomorrow.
     // In preference, use the last trigger date to determine this, since
     // that will avoid possible errors due to daylight savings time changes.
@@ -217,7 +217,7 @@ void DailyTimer::start()
         next = QDateTime(now.date(), mTime);
     else
         next = QDateTime(now.date().addDays(1), mTime);
-    uint interval = next.toTime_t() - now.toTime_t();
+    const qint64 interval = next.toSecsSinceEpoch() - now.toSecsSinceEpoch();
     mTimer->start(interval * 1000);    // execute a single shot
     qCDebug(KALARM_LOG) << "DailyTimer::start: at" << mTime.hour() << ":" << mTime.minute() << ": interval =" << interval/3600 << ":" << (interval/60)%60 << ":" << interval%60;
 }
@@ -231,10 +231,10 @@ void DailyTimer::start()
 void DailyTimer::slotTimer()
 {
     // TIMEZONE = local time
-    QDateTime now = QDateTime::currentDateTime();
+    const QDateTime now = QDateTime::currentDateTime();
     mLastDate = now.date();
-    QDateTime next = QDateTime(mLastDate.addDays(1), mTime);
-    uint interval = next.toTime_t() - now.toTime_t();
+    const QDateTime next = QDateTime(mLastDate.addDays(1), mTime);
+    const qint64 interval = next.toSecsSinceEpoch() - now.toSecsSinceEpoch();
     mTimer->start(interval * 1000);    // execute a single shot
     qCDebug(KALARM_LOG) << "DailyTimer::slotTimer: at" << mTime.hour() << ":" << mTime.minute() << ": interval =" << interval/3600 << ":" << (interval/60)%60 << ":" << interval%60;
 }
