@@ -1,7 +1,7 @@
 /*
  *  timeperiod.h  -  time period data entry widget
  *  Program:  kalarm
- *  Copyright © 2003-2005,2007,2008,2010 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2003-2005,2007,2008,2010 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "timeperiod.h"
+
 #include "combobox.h"
 #include "spinbox.h"
 #include "timespinbox.h"
@@ -46,10 +46,8 @@ static const int maxMinutes = 1000*60-1;   // absolute maximum value for hours:m
 =============================================================================*/
 
 TimePeriod::TimePeriod(bool allowHourMinute, QWidget* parent)
-    : QWidget(parent),
-      mMaxDays(9999),
-      mNoHourMinute(!allowHourMinute),
-      mReadOnly(false)
+    : QWidget(parent)
+    , mNoHourMinute(!allowHourMinute)
 {
     QHBoxLayout* layout = new QHBoxLayout;
     setLayout(layout);
@@ -129,7 +127,7 @@ void TimePeriod::setFocusOnCount()
 */
 void TimePeriod::setMaximum(int hourmin, int days)
 {
-    Duration oldmins = period();
+    const Duration oldmins = period();
     if (hourmin > 0)
     {
         if (hourmin > maxMinutes)
@@ -139,7 +137,7 @@ void TimePeriod::setMaximum(int hourmin, int days)
     mMaxDays = (days >= 0) ? days : 0;
     adjustDayWeekShown();
     setUnitRange();
-    Duration mins = period();
+    const Duration mins = period();
     if (mins != oldmins)
         Q_EMIT valueChanged(mins);
 }
@@ -174,7 +172,7 @@ Duration TimePeriod::period() const
 */
 void TimePeriod::setPeriod(const Duration& perod, bool dateOnly, TimePeriod::Units defaultUnits)
 {
-    Duration oldinterval = period();
+    const Duration oldinterval = period();
     if (!dateOnly  &&  mNoHourMinute)
         dateOnly = true;
     int item;
@@ -221,7 +219,7 @@ void TimePeriod::setPeriod(const Duration& perod, bool dateOnly, TimePeriod::Uni
     setUnitRange();
     showHourMin(item == HoursMinutes  &&  !mNoHourMinute);
 
-    Duration newinterval = period();
+    const Duration newinterval = period();
     if (newinterval != oldinterval)
         Q_EMIT valueChanged(newinterval);
 }
@@ -273,7 +271,7 @@ TimePeriod::Units TimePeriod::setDateOnly(const Duration& perod, bool dateOnly,
 
     if (signal)
     {
-        Duration newinterval = period();
+        const Duration newinterval = period();
         if (newinterval != oldinterval)
             Q_EMIT valueChanged(newinterval);
     }
@@ -285,7 +283,7 @@ TimePeriod::Units TimePeriod::setDateOnly(const Duration& perod, bool dateOnly,
 */
 void TimePeriod::adjustDayWeekShown()
 {
-    Units newMaxUnitShown = (mMaxDays >= 7) ? Weeks : (mMaxDays || mDateOnlyOffset) ? Days : HoursMinutes;
+    const Units newMaxUnitShown = (mMaxDays >= 7) ? Weeks : (mMaxDays || mDateOnlyOffset) ? Days : HoursMinutes;
     if (newMaxUnitShown > mMaxUnitShown)
     {
         if (mMaxUnitShown < Days)
@@ -337,7 +335,7 @@ void TimePeriod::setUnitRange()
 */
 void TimePeriod::setUnits(Units units)
 {
-    Units oldUnits = static_cast<Units>(mUnitsCombo->currentIndex() + mDateOnlyOffset);
+    const Units oldUnits = static_cast<Units>(mUnitsCombo->currentIndex() + mDateOnlyOffset);
     if (units == oldUnits)
         return;
     if (oldUnits == HoursMinutes  &&  units == Minutes)
@@ -350,7 +348,7 @@ void TimePeriod::setUnits(Units units)
         mTimeSpinBox->setValue(mSpinBox->value());
     if (units >= mDateOnlyOffset  &&  units <= mMaxUnitShown)
     {
-        int item = units - mDateOnlyOffset;
+        const int item = units - mDateOnlyOffset;
         mUnitsCombo->setCurrentIndex(item);
         slotUnitsSelected(item);
     }
@@ -363,7 +361,7 @@ TimePeriod::Units TimePeriod::units() const
 {
     return static_cast<Units>(mUnitsCombo->currentIndex() + mDateOnlyOffset);
 }
-    
+
 /******************************************************************************
 *  Called when a new item is made current in the time units combo box.
 */
