@@ -1,7 +1,7 @@
 /*
  *  timespinbox.h  -  time spinbox widget
  *  Program:  kalarm
- *  Copyright © 2001-2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -115,8 +115,8 @@ class TimeSpinBox : public SpinBox2
         int             mMinimumValue;       // real minimum value, excluding special value for "**:**"
         bool            m12Hour;             // use 12-hour clock
         bool            mPm;                 // use PM for manually entered values (with 12-hour clock)
-        bool            mInvalid;            // value is currently invalid (asterisks)
-        bool            mEnteredSetValue;    // to prevent infinite recursion in setValue()
+        bool            mInvalid{false};            // value is currently invalid (asterisks)
+        bool            mEnteredSetValue{false};    // to prevent infinite recursion in setValue()
 };
 
 #endif // TIMESPINBOX_H
