@@ -1,7 +1,7 @@
 /*
  *  prefdlg.h  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright © 2001-2013 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2013 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ class KAlarmPrefDlg : public KPageDialog
 
         static KAlarmPrefDlg* mInstance;
         StackedScrollGroup*   mTabScrollGroup;
-        bool                  mShown;
+        bool                  mShown{false};
         bool                  mValid;
 };
 
