@@ -1,7 +1,7 @@
 /*
  *  repetitionbutton.cpp  -  pushbutton and dialog to specify alarm repetition
  *  Program:  kalarm
- *  Copyright © 2004-2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "repetitionbutton.h"
 
 #include "buttongroup.h"
@@ -43,12 +42,8 @@ using namespace KCalendarCore;
 =============================================================================*/
 
 RepetitionButton::RepetitionButton(const QString& caption, bool waitForInitialisation, QWidget* parent)
-    : QPushButton(caption, parent),
-      mDialog(nullptr),
-      mMaxDuration(-1),
-      mDateOnly(false),
-      mWaitForInit(waitForInitialisation),
-      mReadOnly(false)
+    : QPushButton(caption, parent)
+    , mWaitForInit(waitForInitialisation)
 {
     setCheckable(true);
     setChecked(false);
