@@ -30,8 +30,10 @@
 #include <kalarmcal/compatibilityattribute.h>
 #include <kalarmcal/eventattribute.h>
 
-#include <AkonadiCore/agentmanager.h>
-#include <AkonadiCore/collectionmodifyjob.h>
+#include <AkonadiCore/AgentManager>
+#include <AkonadiCore/ChangeRecorder>
+#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/CollectionModifyJob>
 #include <AkonadiCore/ItemCreateJob>
 #include <AkonadiCore/ItemDeleteJob>
 #include <AkonadiCore/ItemModifyJob>
@@ -47,9 +49,35 @@ namespace
 const QString KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
 const QString KALARM_DIR_RESOURCE(QStringLiteral("akonadi_kalarm_dir_resource"));
 
-Collection::Rights WritableRights = Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem;
+const Collection::Rights WritableRights = Collection::CanChangeItem | Collection::CanCreateItem | Collection::CanDeleteItem;
+
+const QRegularExpression MatchMimeType(QStringLiteral("^application/x-vnd\\.kde\\.alarm.*"),
+                                       QRegularExpression::DotMatchesEverythingOption);
 }
 
+// Class to provide an object for removeDuplicateResources() signals to be received.
+class DuplicateResourceObject : public QObject
+{
+    Q_OBJECT
+public:
+    DuplicateResourceObject(QObject* parent = nullptr) : QObject(parent) {}
+    void reset()  { mAgentPaths.clear(); }
+public Q_SLOTS:
+    void collectionFetchResult(KJob*);
+private:
+    struct ResourceCol
+    {
+        QString    resourceId;    // Akonadi resource identifier
+        ResourceId collectionId;  // Akonadi collection ID
+        ResourceCol() {}
+        ResourceCol(const QString& r, ResourceId c)
+            : resourceId(r), collectionId(c) {}
+    };
+    QHash<QString, ResourceCol> mAgentPaths;   // path, (resource identifier, collection ID) pairs
+};
+DuplicateResourceObject* AkonadiResource::mDuplicateResourceObject{nullptr};
+
+
 Resource AkonadiResource::create(const Akonadi::Collection& collection)
 {
     if (collection.id() < 0  ||  collection.remoteId().isEmpty())
@@ -75,6 +103,8 @@ AkonadiResource::AkonadiResource(const Collection& collection)
         fetchCollectionAttribute(false);
         // If the collection doesn't belong to a resource, it can't be used.
         mValid = AgentManager::self()->instance(mCollection.resource()).isValid();
+
+        connect(AkonadiModel::monitor(), &Monitor::collectionRemoved, this, &AkonadiResource::slotCollectionRemoved);
     }
 }
 
@@ -132,7 +162,7 @@ QUrl AkonadiResource::location() const
 
 QString AkonadiResource::displayLocation() const
 {
-    // Don't simply use remoteId() since that may contain "file://" prefix.
+    // Don't simply use remoteId() since that may contain "file://" prefix, and percent encoding.
     return location().toDisplayString(QUrl::PrettyDecoded | QUrl::PreferLocalFile);
 }
 
@@ -328,6 +358,40 @@ void AkonadiResource::editResource(QWidget* dialogParent)
     }
 }
 
+/******************************************************************************
+* Remove the resource. The calendar file is not removed.
+*  @return true if the resource has been removed or a removal job has been scheduled.
+*  @note The instance will be invalid once it has been removed.
+*/
+bool AkonadiResource::removeResource()
+{
+    if (!isValid())
+        return false;
+    qCDebug(KALARM_LOG) << "AkonadiResource::removeResource:" << id();
+    notifyDeletion();
+    // Note: Don't use CollectionDeleteJob, since that also deletes the backend storage.
+    AgentManager* agentManager = AgentManager::self();
+    const AgentInstance instance = agentManager->instance(configName());
+    if (instance.isValid())
+        agentManager->removeInstance(instance);
+        // The instance will be removed from Resources by slotCollectionRemoved().
+    return true;
+}
+
+/******************************************************************************
+* Called when a monitored collection is removed.
+* If it's this resource, invalidate the resource and remove it from Resources.
+*/
+void AkonadiResource::slotCollectionRemoved(const Collection& collection)
+{
+    if (collection.id() == id())
+    {
+        qCDebug(KALARM_LOG) << "AkonadiResource::slotCollectionRemoved:" << id();
+        disconnect(AkonadiModel::monitor(), nullptr, this, nullptr);
+        ResourceType::removeResource(collection.id());
+    }
+}
+
 bool AkonadiResource::load(bool readThroughCache)
 {
     Q_UNUSED(readThroughCache);
@@ -335,9 +399,9 @@ bool AkonadiResource::load(bool readThroughCache)
     return true;
 }
 
-bool AkonadiResource::isLoaded() const
+bool AkonadiResource::isPopulated() const
 {
-    if (!ResourceType::isLoaded())
+    if (!ResourceType::isPopulated())
     {
         const QModelIndex ix = AkonadiModel::instance()->resourceIndex(mCollection.id());
         if (!ix.data(AkonadiModel::IsPopulatedRole).toBool())
@@ -359,20 +423,6 @@ bool AkonadiResource::save(bool writeThroughCache)
         bool reload() override;
 #endif
 
-/******************************************************************************
-* Close the resource.
-*/
-bool AkonadiResource::close()
-{
-    qCDebug(KALARM_LOG) << "AkonadiResource::close:" << displayName();
-    mCollection.setId(-1);
-    mCollectionAttribute     = CollectionAttribute();
-    mValid                   = false;
-    mHaveCollectionAttribute = false;
-    mNewEnabled              = false;
-    return true;
-}
-
 /******************************************************************************
 * Add an event to the resource, and add it to Akonadi.
 */
@@ -499,8 +549,78 @@ KAEvent AkonadiResource::event(Resource& resource, const Akonadi::Item& item)
     return ev;
 }
 
+/******************************************************************************
+* Get the collection to use for storing an alarm.
+* Optionally, the standard collection for the alarm type is returned. If more
+* than one collection is a candidate, the user is prompted.
+*/
+Resource AkonadiResource::destination(CalEvent::Type type, QWidget* promptParent, bool noPrompt, bool* cancelled)
+{
+    return Resources::destination<AkonadiModel>(type, promptParent, noPrompt, cancelled);
+}
+
+/******************************************************************************
+* Check for, and remove, any Akonadi resources which duplicate use of calendar
+* files/directories.
+*/
+void AkonadiResource::removeDuplicateResources()
+{
+    if (!mDuplicateResourceObject)
+        mDuplicateResourceObject = new DuplicateResourceObject(Resources::instance());
+    mDuplicateResourceObject->reset();
+    const AgentInstance::List agents = AgentManager::self()->instances();
+    for (const AgentInstance& agent : agents)
+    {
+        if (agent.type().mimeTypes().indexOf(MatchMimeType) >= 0)
+        {
+            CollectionFetchJob* job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
+            job->fetchScope().setResource(agent.identifier());
+            connect(job, &CollectionFetchJob::result, mDuplicateResourceObject, &DuplicateResourceObject::collectionFetchResult);
+        }
+    }
+}
+
+/******************************************************************************
+* Called when a removeDuplicateResources() CollectionFetchJob has completed.
+*/
+void DuplicateResourceObject::collectionFetchResult(KJob* j)
+{
+    CollectionFetchJob* job = qobject_cast<CollectionFetchJob*>(j);
+    if (j->error())
+        qCCritical(KALARM_LOG) << "AkonadiResource::collectionFetchResult: CollectionFetchJob" << job->fetchScope().resource()<< "error: " << j->errorString();
+    else
+    {
+        AgentManager* agentManager = AgentManager::self();
+        const Collection::List collections = job->collections();
+        for (const Collection& c : collections)
+        {
+            if (c.contentMimeTypes().indexOf(MatchMimeType) >= 0)
+            {
+                ResourceCol thisRes(job->fetchScope().resource(), c.id());
+                auto it = mAgentPaths.constFind(c.remoteId());
+                if (it != mAgentPaths.constEnd())
+                {
+                    // Remove the resource containing the higher numbered Collection
+                    // ID, which is likely to be the more recently created.
+                    const ResourceCol prevRes = it.value();
+                    if (thisRes.collectionId > prevRes.collectionId)
+                    {
+                        qCWarning(KALARM_LOG) << "AkonadiResource::collectionFetchResult: Removing duplicate resource" << thisRes.resourceId;
+                        agentManager->removeInstance(agentManager->instance(thisRes.resourceId));
+                        continue;
+                    }
+                    qCWarning(KALARM_LOG) << "AkonadiResource::collectionFetchResult: Removing duplicate resource" << prevRes.resourceId;
+                    agentManager->removeInstance(agentManager->instance(prevRes.resourceId));
+                }
+                mAgentPaths[c.remoteId()] = thisRes;
+            }
+        }
+    }
+}
+
 /******************************************************************************
 * Called when a collection has been populated.
+* Stores all its events, even if their alarm types are currently disabled.
 * Emits a signal if all collections have been populated.
 */
 void AkonadiResource::notifyCollectionLoaded(ResourceId id, const QList<KAEvent>& events)
@@ -511,7 +631,7 @@ void AkonadiResource::notifyCollectionLoaded(ResourceId id, const QList<KAEvent>
         AkonadiResource* akres = resource<AkonadiResource>(res);
         if (akres)
         {
-            const CalEvent::Types types = akres->enabledTypes();
+            const CalEvent::Types types = akres->alarmTypes();
             QHash<QString, KAEvent> eventHash;
             for (const KAEvent& event : events)
                 if (event.category() & types)
@@ -556,9 +676,10 @@ void AkonadiResource::notifyCollectionChanged(Resource& res, const Collection& c
     // Check for the collection being enabled/disabled.
     // Enabled/disabled can only be set by KAlarm (not the resource), so if the
     // attribute doesn't exist, it is ignored.
+    const CalEvent::Types oldEnabled = akres->mLastEnabled;
     const CalEvent::Types newEnabled = collection.hasAttribute<CollectionAttribute>()
                                      ? collection.attribute<CollectionAttribute>()->enabled() : CalEvent::EMPTY;
-    if (!akres->mCollectionAttrChecked  ||  newEnabled != akres->mLastEnabled)
+    if (!akres->mCollectionAttrChecked  ||  newEnabled != oldEnabled)
     {
         qCDebug(KALARM_LOG) << "AkonadiResource::setCollectionChanged:" << collection.id() << ": enabled ->" << newEnabled;
         akres->mCollectionAttrChecked = true;
@@ -568,7 +689,7 @@ void AkonadiResource::notifyCollectionChanged(Resource& res, const Collection& c
 
     akres->mCollection = collection;
     if (change != NoChange)
-        Resources::notifySettingsChanged(akres, change);
+        Resources::notifySettingsChanged(akres, change, oldEnabled);
 
     if (!resource<AkonadiResource>(res))
         return;   // this resource has been deleted
@@ -835,11 +956,14 @@ void AkonadiResource::modifyCollectionAttrJobDone(KJob* j)
         AkonadiModel::instance()->refresh(mCollection);   // pick up the modified attribute
         if (newEnabled)
         {
+            const CalEvent::Types oldEnabled = mLastEnabled;
             mLastEnabled = collection.hasAttribute<CollectionAttribute>()
                          ? collection.attribute<CollectionAttribute>()->enabled() : CalEvent::EMPTY;
-            Resources::notifySettingsChanged(this, Enabled);
+            Resources::notifySettingsChanged(this, Enabled, oldEnabled);
         }
     }
 }
 
+#include "akonadiresource.moc"
+
 // vim: et sw=4:
