@@ -240,6 +240,12 @@ public:
     /** Edit the resource's configuration. */
     void editResource(QWidget* dialogParent);
 
+    /** Remove the resource. The calendar file is not removed.
+     *  @return true if the resource has been removed or a removal job has been scheduled.
+     *  @note The instance will be invalid once it has been removed.
+     */
+    bool removeResource();
+
     /** Load the resource from the file, and fetch all events.
      *  If loading is initiated, Resources::resourcePopulated() will be emitted
      *  on completion.
@@ -261,7 +267,7 @@ public:
 #endif
 
     /** Return whether the resource has fully loaded. */
-    bool isLoaded() const;
+    bool isPopulated() const;
 
     /** Save the resource.
      *  Saving is not performed if the resource is disabled.
@@ -274,15 +280,8 @@ public:
      */
     bool save(bool writeThroughCache = true);
 
-    /** Close the resource, without saving it.
-     *  If the resource is currently being saved, it will be closed automatically
-     *  once the save has completed.
-     *
-     *  Derived classes must implement closing in doClose().
-     *
-     *  @return true if closed, false if waiting for a save to complete.
-     */
-    bool close();
+    /** Return whether the resource is waiting for a save() to complete. */
+    bool isSaving() const;
 
     /** Return all events belonging to this resource. */
     QList<KAEvent> events() const;
@@ -350,7 +349,10 @@ inline uint qHash(const Resource& resource, uint seed)
     return qHash(resource.mResource.data(), seed);
 }
 
-/*****************************************************************************/
+
+/*=============================================================================
+* Template definitions.
+*============================================================================*/
 
 template <class Type> bool Resource::is() const
 {
