@@ -28,7 +28,6 @@
 #include "autoqpointer.h"
 #include "akonadiresourcecreator.h"
 #include "calendarmigrator.h"
-#include "collectionmodel.h"
 #include "kalarmapp.h"
 #include "messagebox.h"
 #include "packedlayout.h"
@@ -258,11 +257,11 @@ void ResourceSelector::removeResource()
         if (allTypes != currentType)
         {
             // It also contains alarm types other than the currently displayed type
-            const QString stdTypes = CalendarDataModel::typeListForDisplay(standardTypes);
+            const QString stdTypes = ResourceDataModelBase::typeListForDisplay(standardTypes);
             QString otherTypes;
             const CalEvent::Types nonStandardTypes(allTypes & ~standardTypes);
             if (nonStandardTypes != currentType)
-                otherTypes = xi18nc("@info", "<para>It also contains:%1</para>", CalendarDataModel::typeListForDisplay(nonStandardTypes));
+                otherTypes = xi18nc("@info", "<para>It also contains:%1</para>", ResourceDataModelBase::typeListForDisplay(nonStandardTypes));
             text = xi18nc("@info", "<para><resource>%1</resource> is the default calendar for:%2</para>%3"
                                   "<para>Do you really want to remove it from all calendar lists?</para>", name, stdTypes, otherTypes);
         }
@@ -271,13 +270,13 @@ void ResourceSelector::removeResource()
     }
     else if (allTypes != currentType)
         text = xi18nc("@info", "<para><resource>%1</resource> contains:%2</para><para>Do you really want to remove it from all calendar lists?</para>",
-                     name, CalendarDataModel::typeListForDisplay(allTypes));
+                     name, ResourceDataModelBase::typeListForDisplay(allTypes));
     else
         text = xi18nc("@info", "Do you really want to remove the calendar <resource>%1</resource> from the list?", name);
     if (KAMessageBox::warningContinueCancel(this, text, QString(), KStandardGuiItem::remove()) == KMessageBox::Cancel)
         return;
 
-    CollectionControlModel::removeResource(resource);
+    resource.removeResource();
 }
 
 /******************************************************************************
@@ -520,7 +519,7 @@ void ResourceSelector::showInfo()
         if (altypes & CalEvent::TEMPLATE)
             alarmTypes << i18nc("@info", "Alarm templates");
         const QString alarmTypeString = alarmTypes.join(i18nc("@info List separator", ", "));
-        QString perms = AkonadiModel::readOnlyTooltip(resource);
+        QString perms = ResourceDataModelBase::readOnlyTooltip(resource);
         if (perms.isEmpty())
             perms = i18nc("@info", "Read-write");
         const QString enabled = resource.isEnabled(alarmType)
