@@ -1,7 +1,7 @@
 /*
  *  resourceselector.h  -  alarm calendar resource selection widget
  *  Program:  kalarm
- *  Copyright © 2006-2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2006-2019 David Jarvie <djarvie@kde.org>
  *  Based on KOrganizer's ResourceView class and KAddressBook's ResourceSelection class,
  *  Copyright (C) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
  *  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
@@ -25,14 +25,10 @@
 #ifndef RESOURCESELECTOR_H
 #define RESOURCESELECTOR_H
 
-#include "akonadimodel.h"
-#include "collectionmodel.h"
-
-#include <AkonadiCore/agentinstance.h>
+#include "resources/resource.h"
 
 #include <QFrame>
 #include <QSize>
-#include <QList>
 
 using namespace KAlarmCal;
 
@@ -45,9 +41,6 @@ class QComboBox;
 class QMenu;
 class ResourceView;
 class AkonadiResourceCreator;
-namespace Akonadi {
-    class Collection;
-}
 
 
 /**
@@ -84,32 +77,30 @@ class ResourceSelector : public QFrame
         void  exportCalendar();
         void  showInfo();
         void  archiveDaysChanged(int days);
-        void  resourceAdded(AkonadiResourceCreator*, bool success);
-        void  slotCollectionAdded(const Akonadi::Collection&);
+        void  slotResourceAdded(Resource&, CalEvent::Type);
         void  reinstateAlarmTypeScrollBars();
 
     private:
         CalEvent::Type currentResourceType() const;
-        Akonadi::Collection currentResource() const;
+        Resource currentResource() const;
 
-        CollectionView* mListView;
-        QList<Akonadi::AgentInstance> mAddAgents;   // agent added by addResource()
+        ResourceView*   mListView;
         QComboBox*      mAlarmType;
         QPushButton*    mAddButton;
         QPushButton*    mDeleteButton;
         QPushButton*    mEditButton;
         CalEvent::Type  mCurrentAlarmType;
-        QMenu*          mContextMenu;
-        QAction*        mActionReload;
-        QAction*        mActionShowDetails;
-        QAction*        mActionSetColour;
-        QAction*        mActionClearColour;
-        QAction*        mActionEdit;
-        QAction*        mActionUpdate;
-        QAction*        mActionRemove;
-        QAction*        mActionImport;
-        QAction*        mActionExport;
-        KToggleAction*  mActionSetDefault;
+        QMenu*          mContextMenu{nullptr};
+        QAction*        mActionReload{nullptr};
+        QAction*        mActionShowDetails{nullptr};
+        QAction*        mActionSetColour{nullptr};
+        QAction*        mActionClearColour{nullptr};
+        QAction*        mActionEdit{nullptr};
+        QAction*        mActionUpdate{nullptr};
+        QAction*        mActionRemove{nullptr};
+        QAction*        mActionImport{nullptr};
+        QAction*        mActionExport{nullptr};
+        KToggleAction*  mActionSetDefault{nullptr};
 };
 
 #endif
