@@ -1,7 +1,7 @@
 /*
  *  soundpicker.cpp  -  widget to select a sound file or a beep
  *  Program:  kalarm
- *  Copyright © 2002-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
+#include "soundpicker.h"
 
 #include "autoqpointer.h"
 #include "combobox.h"
@@ -26,7 +26,7 @@
 #include "kalarmapp.h"
 #include "pushbutton.h"
 #include "sounddlg.h"
-#include "soundpicker.h"
+#include "kalarm_debug.h"
 
 #include <kpimtextedit/texttospeech.h>
 
@@ -38,7 +38,6 @@
 #include <QLabel>
 #include <QHBoxLayout>
 #include <QStandardPaths>
-#include "kalarm_debug.h"
 
 
 static QMap<Preferences::SoundType, int> indexes;    // mapping from sound type to combo index
@@ -54,9 +53,7 @@ QString SoundPicker::i18n_combo_File()    { return i18nc("@item:inlistbox", "Sou
 
 
 SoundPicker::SoundPicker(QWidget* parent)
-    : QFrame(parent),
-      mRevertType(false),
-      mReadOnly(false)
+    : QFrame(parent)
 {
     QHBoxLayout* soundLayout = new QHBoxLayout(this);
     soundLayout->setContentsMargins(0, 0, 0, 0);
@@ -73,10 +70,10 @@ SoundPicker::SoundPicker(QWidget* parent)
     // The order of combo box entries must correspond with the 'Type' enum.
     if (indexes.isEmpty())
     {
-        indexes[Preferences::Sound_None]     = 0;
-        indexes[Preferences::Sound_Beep]     = 1;
-        indexes[Preferences::Sound_File] = 2;
-        indexes[Preferences::Sound_Speak]    = 3;
+        indexes[Preferences::Sound_None]  = 0;
+        indexes[Preferences::Sound_Beep]  = 1;
+        indexes[Preferences::Sound_File]  = 2;
+        indexes[Preferences::Sound_Speak] = 3;
     }
 
     mTypeCombo = new ComboBox(mTypeBox);
@@ -317,9 +314,11 @@ void SoundPicker::setLastType()
 * Display a dialog to choose a sound file, initially highlighting any
 * specified file. 'initialFile' must be a full path name or URL.
 * 'defaultDir' is updated to the directory containing the chosen file.
-* Reply = URL selected. If none is selected, URL.isEmpty() is true.
+* @param file  Updated to URL selected, or empty if none is selected.
+* Reply = true if @p file value can be used,
+*       = false if the dialog was deleted while visible.
 */
-QString SoundPicker::browseFile(QString& defaultDir, const QString& initialFile)
+bool SoundPicker::browseFile(QString& file, QString& defaultDir, const QString& initialFile)
 {
     static QString kdeSoundDir;     // directory containing KDE sound files
     if (defaultDir.isEmpty())
@@ -331,10 +330,9 @@ QString SoundPicker::browseFile(QString& defaultDir, const QString& initialFile)
         }
         defaultDir = kdeSoundDir;
     }
-    const QString filter = Phonon::BackendCapabilities::availableMimeTypes().join(QStringLiteral(" "));
-    return KAlarm::browseFile(i18nc("@title:window", "Choose Sound File"), defaultDir, initialFile, filter, true, nullptr);
+    const QString filter = Phonon::BackendCapabilities::availableMimeTypes().join(QLatin1Char(' '));
+    return KAlarm::browseFile(file, i18nc("@title:window", "Choose Sound File"),
+                              defaultDir, initialFile, filter, true, nullptr);
 }
 
-
-
 // vim: et sw=4:
