@@ -1,7 +1,7 @@
 /*
  *  templatepickdlg.cpp  -  dialog to choose an alarm template
  *  Program:  kalarm
- *  Copyright © 2004,2006-2010 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,12 +18,14 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "templatepickdlg.h"
 
+#include "akonadimodel.h"
 #include "functions.h"
 #include "shellprocess.h"
 #include "templatelistview.h"
+#include "resources/eventmodel.h"
+#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 
@@ -31,7 +33,6 @@
 #include <QResizeEvent>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include "kalarm_debug.h"
 
 static const char TMPL_PICK_DIALOG_NAME[] = "TemplatePickDialog";
 
@@ -61,7 +62,7 @@ TemplatePickDlg::TemplatePickDlg(KAEvent::Actions type, QWidget* parent)
         type = static_cast<KAEvent::Actions>(type & ~KAEvent::ACT_COMMAND);
         shown = static_cast<KAEvent::Actions>(shown & ~KAEvent::ACT_COMMAND);
     }
-    mListFilterModel = new TemplateListModel(this);
+    mListFilterModel = TemplateListModel::create<AkonadiModel>(this);
     mListFilterModel->setAlarmActionsEnabled(type);
     mListFilterModel->setAlarmActionFilter(shown);
     mListView = new TemplateListView(topWidget);
@@ -113,5 +114,4 @@ void TemplatePickDlg::resizeEvent(QResizeEvent* re)
     QDialog::resizeEvent(re);
 }
 
-
 // vim: et sw=4:
