@@ -1,7 +1,7 @@
 /*
  *  traywindow.cpp  -  the KDE system tray applet
  *  Program:  kalarm
- *  Copyright © 2002-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,11 +18,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"   //krazy:exclude=includes (kalarm.h must be first)
 #include "traywindow.h"
 
 #include "alarmcalendar.h"
-#include "alarmlistview.h"
+//#include "alarmlistview.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
@@ -32,6 +31,8 @@
 #include "preferences.h"
 #include "synchtimer.h"
 #include "templatemenuaction.h"
+#include "resources/eventmodel.h"
+#include "kalarm_debug.h"
 
 #include <kalarmcal/alarmtext.h>
 
@@ -49,7 +50,6 @@
 #include <QList>
 #include <QTimer>
 #include <QLocale>
-#include "kalarm_debug.h"
 
 #include <stdlib.h>
 #include <limits.h>
@@ -69,11 +69,9 @@ struct TipItem
 =============================================================================*/
 
 TrayWindow::TrayWindow(MainWindow* parent)
-    : KStatusNotifierItem(parent),
-      mAssocMainWindow(parent),
-      mAlarmsModel(nullptr),
-      mStatusUpdateTimer(new QTimer(this)),
-      mHaveDisabledAlarms(false)
+    : KStatusNotifierItem(parent)
+    , mAssocMainWindow(parent)
+    , mStatusUpdateTimer(new QTimer(this))
 {
     qCDebug(KALARM_LOG) << "TrayWindow:";
     setToolTipIconByName(QStringLiteral("kalarm"));
@@ -136,15 +134,16 @@ TrayWindow::TrayWindow(MainWindow* parent)
     MinuteTimer::connect(mToolTipUpdateTimer, SLOT(start()));
 
     // Update when alarms are modified
-    connect(AlarmListModel::all(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+    AlarmListModel* all = AlarmListModel::all<AkonadiModel>();
+    connect(all, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
             mToolTipUpdateTimer, SLOT(start()));
-    connect(AlarmListModel::all(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+    connect(all, SIGNAL(rowsInserted(QModelIndex,int,int)),
             mToolTipUpdateTimer, SLOT(start()));
-    connect(AlarmListModel::all(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
+    connect(all, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
             mToolTipUpdateTimer, SLOT(start()));
-    connect(AlarmListModel::all(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+    connect(all, SIGNAL(rowsRemoved(QModelIndex,int,int)),
             mToolTipUpdateTimer, SLOT(start()));
-    connect(AlarmListModel::all(), SIGNAL(modelReset()),
+    connect(all, SIGNAL(modelReset()),
             mToolTipUpdateTimer, SLOT(start()));
 
     // Set auto-hide status when next alarm or preferences change
