@@ -1,7 +1,7 @@
 /*
  *  wakedlg.cpp  -  dialog to configure wake-from-suspend alarms
  *  Program:  kalarm
- *  Copyright © 2011-2012 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2011-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "wakedlg.h"
 #include "ui_wakedlg.h"
 
@@ -28,7 +27,9 @@
 #include "mainwindow.h"
 #include "messagebox.h"
 #include "preferences.h"
+#include "kalarm_debug.h"
 
+#include <kalarmcal_version.h>
 #include <kalarmcal/kaevent.h>
 
 #include <KLocalizedString>
@@ -36,7 +37,6 @@
 #include <kconfiggroup.h>
 
 #include <QTimer>
-#include "kalarm_debug.h"
 
 using namespace KAlarmCal;
 
@@ -98,7 +98,7 @@ void WakeFromSuspendDlg::enableDisableUseButton()
     bool enable = theApp()->alarmsEnabled();
     if (enable)
     {
-        QString wakeFromSuspendId = KAlarm::checkRtcWakeConfig().value(0);
+        const QString wakeFromSuspendId = KAlarm::checkRtcWakeConfig().value(0);
         const KAEvent event = mMainWindow->selectedEvent();
         enable = event.isValid()
               && event.category() == CalEvent::ACTIVE
@@ -136,10 +136,10 @@ void WakeFromSuspendDlg::showWakeClicked()
         const QStringList params = KAlarm::checkRtcWakeConfig();
         if (!params.isEmpty())
         {
-            KAEvent* event = AlarmCalendar::resources()->event(EventId(params[0].toLongLong(), params[1]));
+            const KAEvent* event = AlarmCalendar::resources()->event(EventId(params[0].toLongLong(), params[1]));
             if (event)
             {
-                mMainWindow->selectEvent(event->itemId());
+                mMainWindow->selectEvent(event->id());
                 return;
             }
         }
@@ -153,7 +153,7 @@ void WakeFromSuspendDlg::showWakeClicked()
 */
 void WakeFromSuspendDlg::useWakeClicked()
 {
-    KAEvent event = mMainWindow->selectedEvent();
+    const KAEvent event = mMainWindow->selectedEvent();
     if (!event.isValid())
         return;
     const KADateTime dt = event.mainDateTime().kDateTime();
@@ -171,12 +171,15 @@ void WakeFromSuspendDlg::useWakeClicked()
                 QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QStringLiteral("wakeupWarning"))
             != KMessageBox::Continue)
         return;
-    int advance = mUi->advanceWakeTime->value();
+    const int advance = mUi->advanceWakeTime->value();
+#if KALARMCAL_VERSION >= QT_VERSION_CHECK(5,12,1)
+    const qint64 triggerTime = dt.addSecs(-advance * 60).toSecsSinceEpoch();
+#else
     unsigned triggerTime = dt.addSecs(-advance * 60).toTime_t();
+#endif
     if (KAlarm::setRtcWakeTime(triggerTime, this))
     {
-        QStringList param;
-        param << QString::number(event.collectionId()) << event.id() << QString::number(triggerTime);
+        const QStringList param{QString::number(event.collectionId()), event.id(), QString::number(triggerTime)};
         KConfigGroup config(KSharedConfig::openConfig(), "General");
         config.writeEntry("RtcWake", param);
         config.sync();
